@@ -7,7 +7,7 @@
 # Distributed under the terms of the GPL
 ###############################################################################
 ###############################################################################
-# Version 0.7.5
+# Version 0.7.6
 ###############################################################################
 ###############################################################################
 # This program recursively downloads Web sites, as it goes, it changes absolute
@@ -163,7 +163,7 @@ proc InitializeDownload {pagina} {
         return
     }
 
-    set directories(base) [Dialogos::SeleccionarDirectorio]
+    set directories(base) [Dialogos::SelectDirectory]
     if {![string compare $directories(base) ""]} {
         return
     }
@@ -564,6 +564,14 @@ proc ChooseDownloads { {map 0} } {
     bind $elegir <KeyPress-Next>  "$texto yview scroll  1 pages"
     bind $elegir <Key-Up>         "$texto yview scroll -1 units"
     bind $elegir <Key-Down>       "$texto yview scroll  1 units"
+    bind $texto  <Button-1>       {
+        tkTextButton1 %W %x %y
+        regexp {(.*)(\.)} [%W index insert] nada line
+        if {$line<$nLinks} {
+            %W.enlaces$line invoke
+        }
+        %W tag remove sel 0.0 end
+    }
 
     grid $marco -sticky news
     grid $texto $barray -sticky news
@@ -1107,7 +1115,7 @@ proc ControlDownloading {listaEnlaces nivelActual paginaMadre} {
                         }
                     }
                 }
-                set direcion(dir)    $tmp_url
+                set direcion(dir)      $tmp_url
                 set directories(local) $tmp_local
             }
         }
@@ -1570,10 +1578,10 @@ proc ReadSupportedLang {} {
         if [regexp {^#|^ |^$} $line] {
             continue
         }
-        set key   [lindex $line 0]
-        set value [lindex $line 1]
+        set language [lindex $line 1]
+        set code     [lindex $line 0]
 
-        set supportedLang($key) $value
+        set supportedLang($language) $code
     }
     return
 }
@@ -1694,7 +1702,7 @@ proc MenusLabels {{labFile ""}} {
     $menus(3)   entryconfigure 1 -label $labelMenus(restoreOrig)    -underline $indexMenus(restoreOrig)
     $menus(3)   entryconfigure 2 -label $labelMenus(configureProxy) -underline $indexMenus(configureProxy)
     $menus(3)   entryconfigure 3 -label $labelMenus(languages)      -underline $indexMenus(languages)
-#   $menus(3)   entryconfigure 4 -label $labelMenus(resource)       -underline $indexMenus(resource)
+#    $menus(3)   entryconfigure 4 -label $labelMenus(resource)      -underline $indexMenus(resource)
 
     .menus      entryconfigure 4 -label $labelMenus(help)           -underline $indexMenus(help)
     $menus(4)   entryconfigure 0 -label $labelMenus(manual)         -underline $indexMenus(manual)
@@ -1797,16 +1805,15 @@ proc CreateMenus {} {
     $menus(3) add command -command Herramientas::RestoreOriginals
     $menus(3) add command -command Herramientas::ConfProxy
     $menus(3) add cascade -menu $menus(3).idiomas
-#   $menus(3) add command -command \
-#          "source [file join "$dirGetleft(main)" Getleft.tcl]"
+#    $menus(3) add command -command \
+#           "source [file join "$dirGetleft(main)" Getleft.tcl]"
 
     set menus(3,0) [menu $menus(3).idiomas -tearoff 0]
-    set list [array get supportedLang]
     set i 0
-    foreach {key name} $list {
-        if [file exists [file join $dirGetleft(languages) menus.$key]] {
-            $menus(3,0) add command -command "ChangeLanguage $key"
-            $menus(3,0) entryconfigure $i -label $name
+    foreach lang [lsort [array names supportedLang]] {
+        if [file exists [file join $dirGetleft(languages) menus.$supportedLang($lang)]] {
+            $menus(3,0) add command -command "ChangeLanguage $supportedLang($lang)"
+            $menus(3,0) entryconfigure $i -label $lang
             incr i
         }
     }
@@ -1851,7 +1858,7 @@ if {![winfo exists .menus]} {
     ReadSupportedLang
     ReadLangFile en
 
-    wm title . "Getleft v 0.7.5"
+    wm title . "Getleft v 0.7.6"
     if [regexp {Windows} $tcl_platform(os)] {
         wm geometry . 300x20
     } else {
